package org.eclipse.jdt.internal.compiler.tool;

package .tmp;

import java.io.File;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.io.Reader;
import java.io.Writer;
import java.net.URI;
import java.net.URISyntaxException;
import java.nio.charset.Charset;
import java.util.zip.ZipEntry;
import java.util.zip.ZipFile;
import javax.lang.model.element.Modifier;
import javax.lang.model.element.NestingKind;
import javax.tools.JavaFileObject;
import org.eclipse.jdt.internal.compiler.classfmt.ClassFileReader;
import org.eclipse.jdt.internal.compiler.classfmt.ClassFormatException;

public class ArchiveFileObject implements JavaFileObject {
  private String entryName;
  
  private File file;
  
  private ZipFile zipFile;
  
  private Charset charset;
  
  public ArchiveFileObject(File file, String entryName, Charset charset) {
    this.entryName = entryName;
    this.file = file;
    this.charset = charset;
  }
  
  protected void finalize() throws Throwable {
    if (this.zipFile != null)
      try {
        this.zipFile.close();
      } catch (IOException iOException) {} 
    super.finalize();
  }
  
  public Modifier getAccessLevel() {
    if (getKind() != JavaFileObject.Kind.CLASS)
      return null; 
    ClassFileReader reader = null;
    try {
      Exception exception2, exception1 = null;
    } catch (ClassFormatException classFormatException) {
    
    } catch (IOException iOException) {}
    if (reader == null)
      return null; 
    int accessFlags = reader.accessFlags();
    if ((accessFlags & 0x1) != 0)
      return Modifier.PUBLIC; 
    if ((accessFlags & 0x400) != 0)
      return Modifier.ABSTRACT; 
    if ((accessFlags & 0x10) != 0)
      return Modifier.FINAL; 
    return null;
  }
  
  public JavaFileObject.Kind getKind() {
    String name = this.entryName.toLowerCase();
    if (name.endsWith(JavaFileObject.Kind.CLASS.extension))
      return JavaFileObject.Kind.CLASS; 
    if (name.endsWith(JavaFileObject.Kind.SOURCE.extension))
      return JavaFileObject.Kind.SOURCE; 
    if (name.endsWith(JavaFileObject.Kind.HTML.extension))
      return JavaFileObject.Kind.HTML; 
    return JavaFileObject.Kind.OTHER;
  }
  
  public NestingKind getNestingKind() {
    ClassFileReader reader;
    switch (getKind()) {
      case SOURCE:
        return NestingKind.TOP_LEVEL;
      case null:
        reader = null;
        try {
          Exception exception2, exception1 = null;
        } catch (ClassFormatException classFormatException) {
        
        } catch (IOException iOException) {}
        if (reader == null)
          return null; 
        if (reader.isAnonymous())
          return NestingKind.ANONYMOUS; 
        if (reader.isLocal())
          return NestingKind.LOCAL; 
        if (reader.isMember())
          return NestingKind.MEMBER; 
        return NestingKind.TOP_LEVEL;
    } 
    return null;
  }
  
  public boolean isNameCompatible(String simpleName, JavaFileObject.Kind kind) {
    return this.entryName.endsWith(String.valueOf(simpleName) + kind.extension);
  }
  
  public boolean delete() {
    throw new UnsupportedOperationException();
  }
  
  public boolean equals(Object o) {
    if (!(o instanceof org.eclipse.jdt.internal.compiler.tool.ArchiveFileObject))
      return false; 
    org.eclipse.jdt.internal.compiler.tool.ArchiveFileObject archiveFileObject = (org.eclipse.jdt.internal.compiler.tool.ArchiveFileObject)o;
    return archiveFileObject.toUri().equals(toUri());
  }
  
  public int hashCode() {
    return toUri().hashCode();
  }
  
  public CharSequence getCharContent(boolean ignoreEncodingErrors) throws IOException {
    if (getKind() == JavaFileObject.Kind.SOURCE) {
      Exception exception1 = null, exception2 = null;
      try {
      
      } finally {
        exception2 = null;
        if (exception1 == null) {
          exception1 = exception2;
        } else if (exception1 != exception2) {
          exception1.addSuppressed(exception2);
        } 
      } 
    } 
    return null;
  }
  
  public long getLastModified() {
    try {
      Exception exception1 = null, exception2 = null;
      try {
      
      } finally {
        exception2 = null;
        if (exception1 == null) {
          exception1 = exception2;
        } else if (exception1 != exception2) {
          exception1.addSuppressed(exception2);
        } 
      } 
    } catch (IOException iOException) {
      return 0L;
    } 
  }
  
  public String getName() {
    return this.entryName;
  }
  
  public InputStream openInputStream() throws IOException {
    if (this.zipFile == null)
      this.zipFile = new ZipFile(this.file); 
    ZipEntry zipEntry = this.zipFile.getEntry(this.entryName);
    return this.zipFile.getInputStream(zipEntry);
  }
  
  public OutputStream openOutputStream() throws IOException {
    throw new UnsupportedOperationException();
  }
  
  public Reader openReader(boolean ignoreEncodingErrors) throws IOException {
    throw new UnsupportedOperationException();
  }
  
  public Writer openWriter() throws IOException {
    throw new UnsupportedOperationException();
  }
  
  public URI toUri() {
    try {
      return new URI("jar:" + this.file.toURI().getPath() + "!" + this.entryName);
    } catch (URISyntaxException uRISyntaxException) {
      return null;
    } 
  }
  
  public String toString() {
    return String.valueOf(this.file.getAbsolutePath()) + "[" + this.entryName + "]";
  }
}
